@@ -1,11 +1,11 @@
-"""
-    Code audit tool for python.
+""" Code audit tool for python.
+
+:copyright: 2013 by Kirill Klenov.
+:license: BSD, see LICENSE for more details.
 
-    :copyright: 2013 by Kirill Klenov.
-    :license: BSD, see LICENSE for more details.
 """
 
-version_info = 1, 3, 3
+version_info = 1, 4, 0
 
 __version__ = version = '.'.join(map(str, version_info))
 __project__ = __name__
